# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About Ad-men](#💼-about-ad-men)
  - [😍 Why is it a big deal for Ad-men customers & partners?](#😍-why-is-it-a-big-deal-for-ad-men-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About Ad-men

> 
Need an efficient, high-performance HR solution for managing your applications?
Choose AD-Men, the No. 1 software for recruitment agencies.



## 😍 Why is it a big deal for Ad-men customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Ad-men customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Ad-men customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Ad-men to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Ad-men.
- ⬅️ Send Jobs data from Ad-men to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Ad-men.

</p>

<p align="center">
<image src=https://github.com/user-attachments/assets/cac7da42-2146-4e67-ac8c-7e37f4550554 width=90% height=100% 
>
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Ad-men**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create jobs in hrflow**](docs/create_jobs_in_hrflow.md) | Send **created** 'job(s)' _from_  _to_ HrFlow |
| [**Update jobs in hrflow**](docs/update_jobs_in_hrflow.md) | Send **updated** 'job(s)' _from_  _to_ HrFlow |
| [**Archive jobs in hrflow**](docs/archive_jobs_in_hrflow.md) | Send **archived** 'job(s)' _from_  _to_ HrFlow |
| [**Create profiles in hrflow**](docs/create_profiles_in_hrflow.md) | Send **created** 'profile(s)' _from_  _to_ HrFlow |
| [**Update profiles in hrflow**](docs/update_profiles_in_hrflow.md) | Send **updated** 'profile(s)' _from_  _to_ HrFlow |
| [**Archive profiles in hrflow**](docs/archive_profiles_in_hrflow.md) | Send **archived** 'profile(s)' _from_  _to_ HrFlow |
| [**Create profiles in **](docs/create_profiles_in_.md) | Send **created** 'profile(s)' _from_ HrFlow _to_  |
| [**Update profiles in **](docs/update_profiles_in_.md) | Send **updated** 'profile(s)' _from_ HrFlow _to_  |
| [**Archive profiles in **](docs/archive_profiles_in_.md) | Send **archived** 'profile(s)' _from_ HrFlow _to_  |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


<p align="center">
<image src=https://github.com/user-attachments/assets/2dead632-4543-4be3-bc6d-d85a49bc31d0 width=90% height=100% 
>
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄 Visit [Ad-men](https://www.ad-rh.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/v2/connectors/admen) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai :  [Nedhir Ebnou](https://github.com/itsnedhir) - Software Engineer
- 🤝 Inasoft : Aurélie CARLESCHI - Operations Director